@@ -121,14 +121,18 @@ def get_function_name(
 ) -> str:
     if isinstance(path, str):
         path = Path(path)
-    if os.environ["GITLAB_CLIENT"] == "True":
+    if os.getenv("CI_PROJECT_NAME"):
         function_name = f"{os.environ['CI_PROJECT_NAME']}/{path.name}:"
     else:
         function_name = f"{env.get_repo_name_auto()}/{path.name}:"
     if latest:
         return f"{function_name}latest"
     elif pr:
-        return f"{function_name}{ref if ref else env.get_env_value('GITHUB_HEAD_REF')}"
+        if os.getenv("CI_MERGE_REQUEST_SOURCE_BRANCH_NAME"):
+            return f"{function_name}{ref if ref else env.get_env_value('CI_MERGE_REQUEST_SOURCE_BRANCH_NAME')}"
+
+        else:
+            return f"{function_name}{ref if ref else env.get_env_value('GITHUB_HEAD_REF')}"
     return f"{function_name}{version}"
 
 
